@@ -1,11 +1,11 @@
 """Pytorch Sphinx theme.
 
-From https://github.com/shiftlab/pytorch_sphinx_theme.
+From https://github.com/pypose/pypose_sphinx_theme.
 
 """
 from os import path
 
-__version__ = '0.0.24'
+__version__ = '0.0.25'
 __version_full__ = __version__
 
 
